==> firestore-api-lib-1.1.8.tgz: package/FirestoreClientMock.ts <==
import Transaction = FirebaseFirestore.Transaction;
import Mock = jest.Mock;

export class FirestoreClientMock {

    public readonly registry: Map<string,FirestoreCollectionMock> = new Map();

    public getCollection<T>(collectionName: string, optionalFields: string[] = []) : FirestoreCollectionMock {
        if (!this.registry.has(collectionName)) {
            this.registry.set(
                collectionName,
                {
                    "documentExists" : jest.fn(),

                    "getDocument" : jest.fn(),

                    "setDocument": jest.fn(),

                    "addDocument": jest.fn(),

                    "updateDocument": jest.fn(),

                    "deleteDocument": jest.fn(),

                    "setDocumentInTransaction": jest.fn(),

                    "executeQuery": jest.fn(),

                    "bulkSet": jest.fn(),

                    "getDocumentsById": jest.fn(),

                    "startQuery" : jest.fn(),

                    "getQueryResult" : jest.fn(),

                    "getSubCollection" : jest.fn(),

                    "listDocuments" : jest.fn()
                } as FirestoreCollectionMock
            )
        }
        return this.registry.get(collectionName)!
    }

    public runTransaction<T>(updateFunction: (transaction: Transaction) => Promise<T>,transactionOptions?:{maxAttempts?: number}
    ): Promise<T> {
        return updateFunction.call("", {} as any);
    }
}

export interface FirestoreCollectionMock {

    "documentExists" : Mock,

    "getDocument" : Mock,

    "setDocument": Mock,

    "addDocument": Mock,

    "deleteDocument": Mock,

    "setDocumentInTransaction": Mock,

    "executeQuery": Mock,

    "bulkSet": Mock,

    "getDocumentsById": Mock,

    "updateDocument" : Mock,

    "startQuery" : Mock,

    "getQueryResult" : Mock,

    "getSubCollection" : Mock,

    "listDocuments" : Mock
}

==> firestore-api-lib-1.2.7.tgz: package/FirestoreClientMock.ts <==
import Transaction = FirebaseFirestore.Transaction;
import Mock = jest.Mock;

export class FirestoreClientMock {

    public readonly registry: Map<string,FirestoreCollectionMock> = new Map();

    public getCollection<T>(collectionName: string, optionalFields: string[] = []) : FirestoreCollectionMock {
        if (!this.registry.has(collectionName)) {
            this.registry.set(
                collectionName,
                {
                    "documentExists" : jest.fn(),

                    "getDocument" : jest.fn(),

                    "setDocument": jest.fn(),

                    "addDocument": jest.fn(),

                    "updateDocument": jest.fn(),

                    "deleteDocument": jest.fn(),

                    "setDocumentInTransaction": jest.fn(),

                    "executeQuery": jest.fn(),

                    "bulkSet": jest.fn(),

                    "getDocumentsById": jest.fn(),

                    "startQuery" : jest.fn(),

                    "getQueryResult" : jest.fn(),

                    "getSubCollection" : jest.fn(),

                    "listDocuments" : jest.fn(),

                    "bulkModification" : jest.fn()
                } as FirestoreCollectionMock
            )
        }
        return this.registry.get(collectionName)!
    }

    public runTransaction<T>(updateFunction: (transaction: Transaction) => Promise<T>,transactionOptions?:{maxAttempts?: number}
    ): Promise<T> {
        return updateFunction.call("", {} as any);
    }
}

export interface FirestoreCollectionMock {

    "documentExists" : Mock,

    "getDocument" : Mock,

    "setDocument": Mock,

    "addDocument": Mock,

    "deleteDocument": Mock,

    "setDocumentInTransaction": Mock,

    "executeQuery": Mock,

    "bulkSet": Mock,

    "getDocumentsById": Mock,

    "updateDocument" : Mock,

    "startQuery" : Mock,

    "getQueryResult" : Mock,

    "getSubCollection" : Mock,

    "listDocuments" : Mock,

    "bulkModification"
}
